<?php

namespace App\Http\Controllers;

use App\Models\Banner;
use Illuminate\Http\Request;

class BannerController extends Controller
{

    public function index()
    {
        $banner = Banner::all();

        return view('backend.modules.banners.index', compact('banner'));
    }


    public function create()
    {
        return view('backend.modules.banners.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'image' => 'required|image|mimes:jpg,jpeg,png,gif,webp|max:2048',
            'subtitle' => 'required|string',
        ]);

        // Handle the image upload
        $image = null;
        if ($request->hasFile('image')) {
            $imageFile = $request->file('image');
            $imageName = time() . '_' . $imageFile->getClientOriginalName();
            $imageFile->move(public_path('images/uploads'), $imageName);
            $image = 'images/uploads/' . $imageName;
        }

        Banner::create([
            'image' => $image,
            'subtitle' => $request->input('subtitle'),
        ]);

        return redirect()->route('banners.index')->with('success', 'Blog created successfully!');
    }



    public function edit($id)
    {
        $banner = Banner::findOrFail($id);

        return view('backend.modules.banners.edit', compact('banner'));
    }


    public function update(Request $request, $id)
    {
        $request->validate([
            'image' => 'nullable|image|mimes:jpg,jpeg,png,gif,webp|max:2048',
            'subtitle' => 'nullable|string',
        ]);

        $banner = Banner::findOrFail($id);

        $image = $banner->image;
        if ($request->hasFile('image')) {
            $imageFile = $request->file('image');
            $imageName = time() . '_' . $imageFile->getClientOriginalName();
            $imageFile->move(public_path('images/uploads'), $imageName);
            $image = 'images/uploads/' . $imageName;
        }

        $banner->update([
            'image' => $image,
            'subtitle' => $request->input('subtitle'),
        ]);

        return redirect()->route('banners.index')->with('success', 'Banner updated successfully!');
    }


    public function destroy($id)
    {
        $banner = Banner::findOrFail($id);
        $banner->delete();

        return redirect()->back()->with('success', 'Banner deleted successfully');
    }
}
