<?php

namespace App\Http\Controllers;

use App\Models\Blogs;
use Illuminate\Http\Request;

class BlogsController extends Controller
{

    public function index()
    {
        $blogs = Blogs::all();

        return view('backend.modules.blogs.index', compact('blogs'));
    }

    public function create()
    {
        return view('backend.modules.blogs.create');
    }


    public function store(Request $request)
    {
        $request->validate([
            'title' => 'required|string|max:255',
            'subtitle' => 'nullable|string',
            'image' => 'required|image|mimes:jpg,jpeg,png,gif,webp|max:2048',
        ]);

        // Handle the image upload
        $image = null;
        if ($request->hasFile('image')) {
            $imageFile = $request->file('image');
            $imageName = time() . '_' . $imageFile->getClientOriginalName();
            $imageFile->move(public_path('images/uploads'), $imageName);
            // Set the image path if the upload is successful
            $image = 'images/uploads/' . $imageName;
        }

        // Create the blog entry with the associated category
        Blogs::create([
            'title' => $request->input('title'),
            'subtitle' => $request->input('subtitle'),
            'image' => $image, // Store image path if available
        ]);

        return redirect()->route('blogs.index')->with('success', 'Blog created successfully!');
    }


    public function edit($id)
    {
        $blogs = Blogs::findOrFail($id);

        return view('backend.modules.blogs.edit', compact('blogs'));
    }

    public function update(Request $request, $id)
    {  // Validate the request
        $request->validate([
            'title' => 'required|string|max:255',
            'subtitle' => 'nullable|string',
            'image' => 'nullable|image|mimes:jpg,jpeg,png,gif,webp|max:2048',
        ]);

        $blog = Blogs::findOrFail($id);

        // Handle the image upload if provided
        $image = $blog->image; // Default to existing image
        if ($request->hasFile('image')) {
            $imageFile = $request->file('image');
            $imageName = time() . '_' . $imageFile->getClientOriginalName();
            $imageFile->move(public_path('images/uploads'), $imageName);
            $image = 'images/uploads/' . $imageName;
        }

        // Update the blog with the new data
        $blog->update([
            'title' => $request->input('title'),
            'subtitle' => $request->input('subtitle'),
            'image' => $image,
        ]);

        return redirect()->route('blogs.index')->with('success', 'Blog updated successfully!');
    }


    public function destroy($id)
    {
        $blogs = Blogs::findOrFail($id);
        $blogs->delete();

        return redirect()->back()->with('success', 'Blogs deleted successfully');
    }
}
