<?php

namespace App\Http\Controllers;

use App\Models\Gallery;
use Illuminate\Http\Request;

class GalleryController extends Controller
{

    public function index()
    {
        $gallery = Gallery::all();

        return view('backend.modules.gallery.index', compact('gallery'));
    }


    public function create()
    {
        return view('backend.modules.gallery.create');
    }


    public function store(Request $request)
    {
        $request->validate([

            'image' => 'required|image|mimes:jpg,jpeg,png,gif,webp|max:2048',
        ]);

        // Handle the image upload
        $image = null;
        if ($request->hasFile('image')) {
            $imageFile = $request->file('image');
            $imageName = time() . '_' . $imageFile->getClientOriginalName();
            $imageFile->move(public_path('images/uploads'), $imageName);
            // Set the image path if the upload is successful
            $image = 'images/uploads/' . $imageName;
        }

        // Create the blog entry with the associated category
        Gallery::create([
            'image' => $image, // Store image path if available
        ]);

        return redirect()->route('gallery.index')->with('success', 'Blog created successfully!');
    }




    public function edit($id)
    {
        $gallery = Gallery::findOrFail($id);

        return view('backend.modules.gallery.edit', compact('gallery'));
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'image' => 'nullable|image|mimes:jpg,jpeg,png,gif,webp|max:2048',
        ]);

        $gallery = Gallery::findOrFail($id);

        // Handle the image upload if provided
        $image = $gallery->image; // Default to existing image
        if ($request->hasFile('image')) {
            $imageFile = $request->file('image');
            $imageName = time() . '_' . $imageFile->getClientOriginalName();
            $imageFile->move(public_path('images/uploads'), $imageName);
            $image = 'images/uploads/' . $imageName;
        }

        // Update the gallery with the new data
        $gallery->update([
            'image' => $image,
        ]);

        return redirect()->route('gallery.index')->with('success', 'Gallery updated successfully!');
    }

    public function destroy($id)
    {
        $gallery = Gallery::findOrFail($id);
        $gallery->delete();

        return redirect()->back()->with('success', 'Gallery deleted successfully');
    }
}
