<?php

namespace App\Http\Controllers;

use Illuminate\Support\Facades\DB;

use App\Mail\ReservationConfirmation;
use Illuminate\Support\Facades\Mail;

use Illuminate\Support\Facades\Hash;

use Illuminate\Http\Request;
use App\Models\Reservation;
use App\Models\Seat;
use App\Models\User;

class ReceptionistController extends Controller
{

    public function index(Request $request)
    {
        $selectedDate = $request->input('reservation_date', now()->toDateString());

        $reservation = Reservation::all();

        // Fetch all seats with reservations for the selected date
        $seats = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->get();
        // Fetch individual seats with the same filter logic
        $vvip1 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(1);

        $vvip2 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(2);

        $vvip3 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(3);

        $vvip4 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(4);

        $vip1 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(5);

        $vip2 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(6);

        $vip3 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(7);

        $vip4 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(8);

        $vip5 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(9);

        $vip6 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(10);

        $vip7 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(11);

        return view('backend.modules.seats-map-receptionist.index', compact('seats', 'vvip1', 'vvip2', 'vvip3', 'vvip4', 'vip1', 'vip2', 'vip3', 'vip4', 'vip5', 'vip6', 'vip7', 'selectedDate', 'reservation'));
    }
    public function store(Request $request)
    {
        // Validate incoming data
        $validatedData = $request->validate([
            'seat_id' => 'required|exists:seats,id', // The seat_id will refer to VVIP, VIP, or ST
            'fullName' => 'required|string|max:255',
            'contactNumber' => 'required|string|max:15',
            'emailAddress' => 'required|email',
            'reservationDate' => 'required|date',
            'eta' => 'required|date_format:H:i',
            'guests' => 'required|integer|min:1',
            'notes' => 'nullable|string',
            'amount_to_pay' => 'required|numeric|min:0',
        ]);

        // Use a transaction to ensure atomicity
        DB::transaction(function () use ($validatedData) {
            // Create a new reservation
            $reservation = Reservation::create([
                'seat_id' => $validatedData['seat_id'], // The seat_id refers to the selected seat
                'full_name' => $validatedData['fullName'],
                'contact_number' => $validatedData['contactNumber'],
                'email' => $validatedData['emailAddress'],
                'reservation_date' => $validatedData['reservationDate'],
                'estimated_time_arrival' => $validatedData['eta'],
                'number_of_guests' => $validatedData['guests'],
                'amount_to_pay' => $validatedData['amount_to_pay'], // Use the amount passed from the form
                'notes' => $validatedData['notes'],
            ]);

            // Update the seat status to 'occupied'
            Seat::where('id', $validatedData['seat_id'])->update(['status' => 'occupied']);

            // Send the reservation confirmation email
            $fullName = $validatedData['fullName'];  // Assuming you have a way to fetch the seat name
            $guests = $validatedData['guests'];
            $amountToPay = $validatedData['amount_to_pay'];

            // Send email
            Mail::to($validatedData['emailAddress'])->send(new ReservationConfirmation($fullName, $guests, $amountToPay));
        });

        return redirect()->route('receptionist.map')->with('success', 'Reservation successfully created and email sent!');
    }

    public function receptionistLists()
    {
        // Fetch all users with the 'receptionist' role
        $receptionists = User::all();

        // Pass the receptionists data to the view
        return view('backend.modules.receptionist.index', compact('receptionists'));
    }

    public function createReceptionistUser()
    {
        return view('backend.modules.receptionist.create');
    }

    public function storeReceptionistUser(Request $request)
    {
        // Validate incoming request data
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|unique:users,email',
            'password' => 'required',
            'roles' => 'required|string',
        ]);

        // Create the receptionist (a user with a default role of "receptionist")
        $receptionist = User::create([
            'name' => $request->name,  // Store fullname as name
            'email' => $request->email,
            'password' => Hash::make($request->input('password')),
            'roles' => $request->input('roles'),
        ]);

        // Optionally, you can return a success message or redirect the user
        return redirect()->route('admin.receptionist')->with('success', 'Receptionist created successfully.');
    }

    // Edit a receptionist
    public function edit($id)
    {
        $receptionist = User::findOrFail($id);
        return view('backend.modules.receptionist.edit', compact('receptionist'));
    }

    // Update a receptionist's details
    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string',
            'email' => 'required|string|email|unique:users,email,' . $id,
            'password' => 'required|string|min:8',
            'roles' => 'required|string'
        ]);

        $user = User::findOrFail($id);

        $user->name = $request->input('name');
        $user->email = $request->input('email');

        // Update password only if provided
        if ($request->filled('password')) {
            $user->password = Hash::make($request->input('password'));
        }

        $user->roles = $request->input('roles');
        $user->save();

        return redirect()->route('admin.receptionist')->with('success', 'Receptionist updated successfully.');
    }

    // Delete a receptionist
    public function destroy($id)
    {
        $receptionist = User::findOrFail($id);
        $receptionist->delete();

        return redirect()->route('admin.receptionist')->with('success', 'Receptionist deleted successfully.');
    }
}
