<?php

namespace App\Mail;

use Illuminate\Bus\Queueable;
use Illuminate\Mail\Mailable;
use Illuminate\Queue\SerializesModels;
use App\Models\Seat; // Import the Seat model

class SeatCheckedOut extends Mailable
{
    use Queueable, SerializesModels;

    public $fullName;
    public $seatName; // Update to store seat name

    /**
     * Create a new message instance.
     *
     * @param string $fullName
     * @param int $seatId
     */
    public function __construct($fullName, $seatId)
    {
        $this->fullName = $fullName;

        // Fetch the seat name from the Seat model
        $seat = Seat::find($seatId);
        $this->seatName = $seat ? $seat->name : 'Unknown Seat'; // Default to 'Unknown Seat' if not found
    }

    /**
     * Build the message.
     *
     * @return $this
     */
    public function build()
    {
        // Construct the email subject using the seat name
        $emailSubject = "XCLV {$this->seatName} Checkout";

        return $this->view('emails.seat_checked_out')
                    ->with('fullName', $this->fullName)
                    ->subject($emailSubject);
    }
}
