<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Seat extends Model
{
    use HasFactory;

    protected $fillable = [
        'name',
        'time',
        'price',
        'status',
        'seat_available',
        'show_price',
        'door_charge',
    ];

    protected $casts = [
        'show_price' => 'boolean',
    ];

    // Define the relationship with the Reservation model
    public function reservations()
    {
        return $this->hasMany(Reservation::class);
    }

    public function events()
    {
        return $this->hasMany(EventTable::class, 'seat_id');
    }
    public function unavailable()
    {
        return $this->hasMany(SeatSchedule::class, 'seat_id');
    }
    public function priceForDate($selectedDate)
    {
        // Assuming 'date' is a field in the related 'Date' model, you need to filter by it
        $event = $this->events()
            ->whereHas('date', function ($query) use ($selectedDate) {
                $query->where('date', $selectedDate);
            })
            ->first();

        // Return the event price if available, otherwise fallback to default price
        return $event ? $event->price : $this->price;
    }
    public function doorchargeForDate($selectedDate)
    {
        // Assuming 'date' is a field in the related 'Date' model, you need to filter by it
        $event = $this->events()
            ->whereHas('date', function ($query) use ($selectedDate) {
                $query->where('date', $selectedDate);
            })
            ->first();

        // Return the event price if available, otherwise fallback to default price
        return $event ? $event->door_charge : $this->door_charge;
    }
}
