<x-app-layout>
    <div class="container p-6 mx-auto">

        <div class="flex justify-between items-center py-4">
            <div>
                <h1 class="text-3xl font-extrabold text-gray-800">User Management</h1>
            </div>


            <!-- Add New Receptionist Button -->
            <div class="">
                <a href="{{ route('admin.receptionist.create') }}"
                    class="inline-block px-6 py-3 bg-gray-800 text-white font-semibold rounded-lg shadow-md hover:bg-[#ef5400] transition duration-300">
                    + Add New User
                </a>
            </div>
        </div>


        <!-- Success Message -->
        @if (session('success'))
        <div class="p-4 mb-6 text-white bg-green-600 rounded-lg shadow">
            {{ session('success') }}
        </div>
        @endif

        <!-- Receptionist Table -->
        <div class="overflow-hidden ">
            <div class="overflow-x-auto">
                <table id="receptionistsTable" class="min-w-full bg-white border border-gray-200">
                    <thead class="bg-gray-100">
                        <tr>
                            <th class="px-6 py-3 text-sm font-medium tracking-wider text-left text-gray-700 uppercase border-b border-gray-200">
                                Full Name
                            </th>
                            <th class="px-6 py-3 text-sm font-medium tracking-wider text-left text-gray-700 uppercase border-b border-gray-200">
                                Email
                            </th>
                            <th class="px-6 py-3 text-sm font-medium tracking-wider text-left text-gray-700 uppercase border-b border-gray-200">
                                Role
                            </th>
                            <th class="px-6 py-3 text-sm font-medium tracking-wider text-center text-gray-700 uppercase border-b border-gray-200">
                                Actions
                            </th>
                        </tr>
                    </thead>
                    <tbody class="divide-y divide-gray-200">
                        @foreach ($receptionists as $receptionist)
                        <tr class="hover:bg-gray-50">
                            <td class="px-6 py-4 text-sm text-gray-800">
                                {{ $receptionist->name }}
                            </td>
                            <td class="px-6 py-4 text-sm text-gray-800">
                                {{ $receptionist->email }}
                            </td>
                            <td class="px-6 py-4 text-sm text-gray-800">
                                {{ $receptionist->roles }}
                            </td>
                            <td class="px-6 py-4 text-center">
                                <div class="flex space-x-4">
                                    <!-- Edit Button -->
                                    <a href="{{ route('admin.receptionist.edit', $receptionist->id) }}"
                                        class="inline-block px-4 py-2 text-sm font-medium text-white transition bg-blue-500 rounded-lg hover:bg-blue-700">
                                        Edit
                                    </a>

                                    <!-- Delete Button Triggering Modal -->
                                    <button type="button"
                                        class="inline-block px-4 py-2 text-sm font-medium text-white transition bg-red-500 rounded-lg hover:bg-red-700"
                                        onclick="showDeleteModal('{{ route('admin.receptionist.destroy', $receptionist->id) }}')">
                                        Delete
                                    </button>


                                </div>
                            </td>
                        </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
        </div>

    </div>
    <!-- Delete Confirmation Modal -->
    <div id="deleteModal" class="hidden fixed inset-0 flex items-center justify-center bg-black bg-opacity-50 z-50">
        <div class="bg-white rounded-lg shadow-lg p-6 w-96">
            <h2 class="text-lg font-semibold text-gray-800">Confirm Deletion</h2>
            <p class="mt-2 text-sm text-gray-600">Are you sure you want to delete this user?</p>
            <div class="mt-6 flex justify-end space-x-4">
                <button onclick="hideDeleteModal()"
                    class="px-4 py-2 text-sm font-medium text-gray-700 border border-gray-300 rounded-lg hover:bg-gray-100">
                    Cancel
                </button>
                <form id="deleteForm" method="POST">
                    @csrf
                    @method('DELETE')
                    <button type="submit"
                        class="px-4 py-2 text-sm font-medium text-white bg-red-500 rounded-lg hover:bg-red-700">
                        Delete
                    </button>
                </form>
            </div>
        </div>
    </div>

    <!-- JavaScript for Modal Control -->
    <script>
        function showDeleteModal(actionUrl) {
            const modal = document.getElementById('deleteModal');
            const form = document.getElementById('deleteForm');
            form.action = actionUrl;
            modal.classList.remove('hidden');
        }

        function hideDeleteModal() {
            const modal = document.getElementById('deleteModal');
            modal.classList.add('hidden');
        }
    </script>
    <!-- Include DataTables CDN -->
    <link rel="stylesheet" href="https://cdn.datatables.net/1.13.6/css/jquery.dataTables.min.css">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/jquery.dataTables.min.js"></script>

    <script>
        // Initialize DataTable
        $(document).ready(function() {
            $('#receptionistsTable').DataTable({
                responsive: true,
                paging: true,
                searching: true,
                info: true,
                columnDefs: [{
                        orderable: false,
                        targets: 0
                    } // Disable ordering for the Actions column
                ],
                language: {
                    search: "Filter:",
                    lengthMenu: "Show _MENU_ entries",
                }
            });
        });
    </script>
</x-app-layout>