<x-app-layout>
    <div class="container p-6 mx-auto bg-white rounded-lg shadow-md">
        <h1 class="mb-6 text-2xl font-bold text-center text-gray-700">Edit Seat</h1>

        <form action="{{ route('admin.seats.update', $seat->id) }}" method="POST">
            @csrf
            @method('PUT')

            <!-- Seat Name -->
            <div class="mb-4">
                <label for="name" class="block text-sm font-medium text-gray-700">Seat Name</label>
                <input type="text" id="name" name="name" value="{{ $seat->name }}"
                    class="w-full p-2 mt-2 border rounded-lg" readonly>
            </div>

            <!-- Price -->
            <div class="mb-4">
                <label for="price" class="block text-sm font-medium text-gray-700">Consumables</label>
                <input type="text" id="price" name="price" value="{{ $seat->price }}"
                    class="w-full p-2 mt-2 border rounded-lg">
            </div>

            <div class="mb-4">
                <label for="door_charge" class="block text-sm font-medium text-gray-700">Door Charge</label>
                <input type="text" id="door_charge" name="door_charge" value="{{ $seat->door_charge }}"
                    class="w-full p-2 mt-2 border rounded-lg">
            </div>

            <!-- Seat Available -->
            <div class="mb-4">
                <label for="seat_available" class="block text-sm font-medium text-gray-700">Seat Available</label>
                <input type="number" id="seat_available" name="seat_available" value="{{ $seat->seat_available }}"
                    class="w-full p-2 mt-2 border rounded-lg">
            </div>

            <!-- Show Price -->
            <div class="mb-4">
                <label for="show_price" class="block text-sm font-medium text-gray-700">Show Consumables</label>
                <select id="show_price" name="show_price" class="w-full p-2 mt-2 border rounded-lg">
                    <option value="1" {{ $seat->show_price ? 'selected' : '' }}>Yes</option>
                    <option value="0" {{ !$seat->show_price ? 'selected' : '' }}>No</option>
                </select>
            </div>

            <!-- Time -->
            <div class="mb-4">
                <label for="add_time" class="block text-sm font-medium text-gray-700">Add Time</label>
                <div class="flex space-x-2">
                    <input type="time" id="add_time" placeholder="Enter time (e.g., 2:00 PM)"
                        class="flex-grow p-2 border rounded-lg">
                    <button type="button" id="add_time_btn"
                        class="px-4 text-white bg-green-500 rounded-lg hover:bg-green-600">
                        Add
                    </button>
                </div>
                <!-- Display Added Times -->
                <ul id="time_list" class="mt-2 space-y-1">
                    @foreach(explode(',', $seat->time) as $time)
                    @if($time)
                    <li class="flex items-center space-x-2">
                        <span>{{ $time }}</span>
                        <button type="button" class="text-red-500 remove_time hover:text-red-700">Remove</button>
                    </li>
                    @endif
                    @endforeach
                </ul>
                <!-- Hidden Input to Store Times -->
                <input type="hidden" id="time" name="time" value="{{ $seat->time }}">
            </div>

            <!-- Buttons -->
            <div class="flex items-center justify-between">
                <a href="{{ route('admin.seats') }}" class="text-sm text-gray-500 underline hover:text-gray-700">
                    Cancel
                </a>
                <button type="submit"
                    class="px-4 py-2 font-semibold text-white bg-blue-500 rounded-lg hover:bg-blue-600">
                    Update Seat
                </button>
            </div>
        </form>
    </div>

    <!-- JavaScript -->
    <script>
        document.addEventListener('DOMContentLoaded', () => {
            const addTimeBtn = document.getElementById('add_time_btn');
            const timeInput = document.getElementById('add_time');
            const timeList = document.getElementById('time_list');
            const hiddenInput = document.getElementById('time');

            // Add Time to List
            addTimeBtn.addEventListener('click', () => {
                const timeValue = timeInput.value.trim();
                if (timeValue) {
                    // Add new time to the list
                    const listItem = document.createElement('li');
                    listItem.classList.add('flex', 'items-center', 'space-x-2');
                    listItem.innerHTML = `
                        <span>${timeValue}</span>
                        <button type="button" class="text-red-500 remove_time hover:text-red-700">Remove</button>
                    `;
                    timeList.appendChild(listItem);

                    // Update hidden input
                    updateHiddenInput();

                    // Clear the input field
                    timeInput.value = '';
                }
            });

            // Remove Time from List
            timeList.addEventListener('click', (e) => {
                if (e.target.classList.contains('remove_time')) {
                    e.target.parentElement.remove();
                    updateHiddenInput();
                }
            });

            // Update Hidden Input with List Values
            function updateHiddenInput() {
                const times = Array.from(timeList.querySelectorAll('span')).map(span => span.textContent);
                hiddenInput.value = times.join(',');
            }
        });
    </script>
</x-app-layout>