<?php

use App\Models\Blogs;
use App\Models\Banner;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\PageController;
use App\Http\Controllers\SeatController;
use App\Http\Controllers\BlogsController;
use App\Http\Controllers\BannerController;
use App\Http\Controllers\GalleryController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\ContactUsController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\EventTableController;
use App\Http\Controllers\ReservationController;
use App\Http\Controllers\ReceptionistController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/




Route::get('/', [PageController::class, 'home']);
Route::get('/about_us', [PageController::class, 'about_us']);
Route::get('/contact_us', [PageController::class, 'contact_us']);

Route::get('/blogs', [PageController::class, 'blogs']);
Route::get('/blogs_details/{id}', [PageController::class, 'blogs_details']);

Route::get('/gallery', [PageController::class, 'gallery']);
Route::get('/xclvdvoreservations', [PageController::class, 'reservation'])->name('user.reservation');
Route::post('/reservation/user/success', [ReservationController::class, 'store'])->name('user.reservations.store');
Route::post('/reservation', [PageController::class, 'reservation'])->name('reservations.index');
Route::post('reservation/cancel/{reservation}', [ReservationController::class, 'cancel'])->name('reservation.cancel');
Route::delete('/events/delete/{id}', [EventTableController::class, 'delete'])->name('events.delete.events');
Route::post('/get-available-times', [PageController::class, 'getAvailableTimes'])->name('get.available.times');
Route::post('/reservation/success', [ReceptionistController::class, 'store'])->name('reservations.store');
Route::get('/receptionist/reservation', [ReceptionistController::class, 'index'])->name('receptionist.map');
Route::get('/reservations/export', [ReservationController::class, 'export'])->name('reservations.export');
Route::post('/save-form', [ContactUsController::class, 'store'])->name('save.form');
Route::post('/status_unavailable', [DashboardController::class, 'status_unavailable'])->name('status.unavailable');

Route::get('/dashboard', function () {
    return view('dashboard');
})->middleware(['auth', 'verified'])->name('dashboard');

Route::middleware('auth')->prefix('admin')->group(function () {
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');
    Route::resource('/blogs', BlogsController::class);
    Route::resource('/contacts', ContactUsController::class);
    Route::resource('/gallery', GalleryController::class);
    Route::resource('/banners', BannerController::class);
    Route::get('/seats/map/admin', [DashboardController::class, 'index'])->name('admin.seats.map');
    Route::get('/seats/map/admin/result', [DashboardController::class, 'showSeats'])->name('showSeats');
    Route::post('/events/store', [EventTableController::class, 'store'])->name('events.store');
    Route::get('/events/create', [EventTableController::class, 'create'])->name('events.create');
    Route::get('/receptionist', [ReceptionistController::class, 'receptionistLists'])->name('admin.receptionist');
    Route::get('/receptionist/create', [ReceptionistController::class, 'createReceptionistUser'])->name('admin.receptionist.create');
    Route::post('/receptionist/create/success', [ReceptionistController::class, 'storeReceptionistUser'])->name('admin.receptionist.store');
    Route::get('/receptionists/{id}/edit', [ReceptionistController::class, 'edit'])->name('admin.receptionist.edit');
    Route::put('/receptionists/{id}', [ReceptionistController::class, 'update'])->name('admin.receptionist.update');
    Route::delete('/receptionists/{id}', [ReceptionistController::class, 'destroy'])->name('admin.receptionist.destroy');
    Route::get('/events/edit/{id}', [EventTableController::class, 'edit'])->name('events.edit_events');
    Route::put('/events/update/{id}', [EventTableController::class, 'update'])->name('events.update');
    Route::get('/events/show_events/{id}', [EventTableController::class, 'show_events'])->name('events.show_events');
    Route::get('/seats', [SeatController::class, 'index'])->name('admin.seats');
    Route::get('/edit/{id}', [SeatController::class, 'edit'])->name('admin.seats.edit');
    Route::put('/seats/{id}', [SeatController::class, 'update'])->name('admin.seats.update');
    Route::get('/reservation', [ReservationController::class, 'index'])->name('admin.reservation');
    Route::patch('/reservations/{id}/confirm', [ReservationController::class, 'confirm'])->name('user.reservations.confirm');
    Route::delete('/reservations/{id}', [ReservationController::class, 'destroy'])->name('user.reservations.destroy');
    Route::get('/seats/map/receptionist', [ReceptionistController::class, 'index'])->name('receptionist.map.show');
    Route::post('/update-seat-status', [DashboardController::class, 'updateSeatStatus'])->name('update.seat.status');
    Route::post('/update_seat_status', [DashboardController::class, 'update_Seat_Status'])->name('update_seat_status');
});

Route::get('/optimize', function () {
    Artisan::call('route:cache');
    Artisan::call('view:clear');
    Artisan::call('cache:clear');
    return 1;
});

require __DIR__ . '/auth.php';
